<img src="https://unpackai.github.io/unpackai_logo.svg" alt="unpackAI Logo" width="75%"/>

# unpackAI

[![PyPI version](https://img.shields.io/pypi/v/unpackai)](https://pypi.org/project/unpackai/)
![Python version](https://img.shields.io/pypi/pyversions/unpackai)
![License](https://img.shields.io/github/license/unpackai/unpackai)
![PyPI Downloads](https://img.shields.io/pypi/dm/unpackai)

[![Bugs](https://img.shields.io/github/issues/unpackai/unpackai/bug)](https://github.com/unpackai/unpackai/issues?q=is%3Aissue+is%3Aopen+-label%3A"enhancement")
[![Enhancements](https://img.shields.io/github/issues/unpackai/unpackai/enhancement)](https://github.com/unpackai/unpackai/issues?q=is%3Aissue+is%3Aopen+label%3A"enhancement")
[![Coverage Status](https://coveralls.io/repos/github/unpackAI/unpackai/badge.svg?branch=main)](https://coveralls.io/github/unpackAI/unpackai?branch=main)


> AI & Machine Learning Education as accessible as possible.
> -- <cite>unpackAI</cite>

The [unpackAI](https://unpackai.com/) library ease your learning of state-of-the-art deep learning to empower your business and career.

## Installation

You can install this library with pip

```shell
pip install unpackai
```

or with github link to get the latest version

```shell
pip install git+https://github.com/unpackai/unpackai/
```

## Content

This package provides utilities for:

* Computer Vision (CV)
* Natural Language Processing (NLP)

## Documentation

Documentation is available [here](https://unpackai.github.io/unpackai).
